#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-octave-qscintilla.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/m-editor/moc-octave-qscintilla.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-octave-qscintilla.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6octave17octave_qscintillaE_t {};
} // unnamed namespace

template <> constexpr inline auto octave::octave_qscintilla::qt_create_metaobjectdata<qt_meta_tag_ZN6octave17octave_qscintillaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "octave::octave_qscintilla",
        "update_rowcol_indicator_signal",
        "",
        "line",
        "col",
        "execute_command_in_terminal_signal",
        "create_context_menu_signal",
        "QMenu*",
        "context_menu_edit_signal",
        "qsci_has_focus_signal",
        "status_update",
        "show_doc_signal",
        "show_symbol_tooltip_signal",
        "QPoint",
        "context_menu_break_condition_signal",
        "context_menu_break_once",
        "ctx_menu_run_finished_signal",
        "QPointer<QTemporaryFile>",
        "focus_console_after_command_signal",
        "interpreter_event",
        "fcn_callback",
        "fcn",
        "meth_callback",
        "meth",
        "handle_enter_debug_mode",
        "handle_exit_debug_mode",
        "ctx_menu_run_finished",
        "contextmenu_help",
        "contextmenu_doc",
        "contextmenu_help_doc",
        "contextmenu_edit",
        "contextmenu_run",
        "contextmenu_run_temp_error",
        "contextmenu_break_condition",
        "contextmenu_break_once",
        "text_changed",
        "cursor_position_changed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'update_rowcol_indicator_signal'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'execute_command_in_terminal_signal'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'create_context_menu_signal'
        QtMocHelpers::SignalData<void(QMenu *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'context_menu_edit_signal'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'qsci_has_focus_signal'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'status_update'
        QtMocHelpers::SignalData<void(bool, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'show_doc_signal'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'show_symbol_tooltip_signal'
        QtMocHelpers::SignalData<void(const QPoint &, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'context_menu_break_condition_signal'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'context_menu_break_once'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'ctx_menu_run_finished_signal'
        QtMocHelpers::SignalData<void(int, QPointer<QTemporaryFile>, QPointer<QTemporaryFile>, bool, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 17, 2 }, { 0x80000000 | 17, 2 }, { QMetaType::Bool, 2 },
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'focus_console_after_command_signal'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const fcn_callback &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'interpreter_event'
        QtMocHelpers::SignalData<void(const meth_callback &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'handle_enter_debug_mode'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handle_exit_debug_mode'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ctx_menu_run_finished'
        QtMocHelpers::SlotData<void(int, QPointer<QTemporaryFile>, QPointer<QTemporaryFile>, bool, bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 17, 2 }, { 0x80000000 | 17, 2 }, { QMetaType::Bool, 2 },
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_help'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_doc'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_help_doc'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_edit'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_run'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_run_temp_error'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'contextmenu_break_condition'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'contextmenu_break_once'
        QtMocHelpers::SlotData<void(const QPoint &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'text_changed'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cursor_position_changed'
        QtMocHelpers::SlotData<void(int, int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<octave_qscintilla, qt_meta_tag_ZN6octave17octave_qscintillaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject octave::octave_qscintilla::staticMetaObject = { {
    QMetaObject::SuperData::link<QsciScintilla::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17octave_qscintillaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17octave_qscintillaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6octave17octave_qscintillaE_t>.metaTypes,
    nullptr
} };

void octave::octave_qscintilla::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<octave_qscintilla *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->update_rowcol_indicator_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->execute_command_in_terminal_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->create_context_menu_signal((*reinterpret_cast<std::add_pointer_t<QMenu*>>(_a[1]))); break;
        case 3: _t->context_menu_edit_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->qsci_has_focus_signal((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->status_update((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 6: _t->show_doc_signal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->show_symbol_tooltip_signal((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->context_menu_break_condition_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->context_menu_break_once((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->ctx_menu_run_finished_signal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 11: _t->focus_console_after_command_signal(); break;
        case 12: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<fcn_callback>>(_a[1]))); break;
        case 13: _t->interpreter_event((*reinterpret_cast<std::add_pointer_t<meth_callback>>(_a[1]))); break;
        case 14: _t->handle_enter_debug_mode(); break;
        case 15: _t->handle_exit_debug_mode(); break;
        case 16: _t->ctx_menu_run_finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPointer<QTemporaryFile>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 17: _t->contextmenu_help((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->contextmenu_doc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->contextmenu_help_doc((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->contextmenu_edit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->contextmenu_run((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->contextmenu_run_temp_error(); break;
        case 23: _t->contextmenu_break_condition((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->contextmenu_break_once((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 25: _t->text_changed(); break;
        case 26: _t->cursor_position_changed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(int , int )>(_a, &octave_qscintilla::update_rowcol_indicator_signal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(const QString & )>(_a, &octave_qscintilla::execute_command_in_terminal_signal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(QMenu * )>(_a, &octave_qscintilla::create_context_menu_signal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(const QString & )>(_a, &octave_qscintilla::context_menu_edit_signal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(bool )>(_a, &octave_qscintilla::qsci_has_focus_signal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(bool , bool )>(_a, &octave_qscintilla::status_update, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(const QString & )>(_a, &octave_qscintilla::show_doc_signal, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(const QPoint & , const QString & )>(_a, &octave_qscintilla::show_symbol_tooltip_signal, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(int )>(_a, &octave_qscintilla::context_menu_break_condition_signal, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(int )>(_a, &octave_qscintilla::context_menu_break_once, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(int , QPointer<QTemporaryFile> , QPointer<QTemporaryFile> , bool , bool )>(_a, &octave_qscintilla::ctx_menu_run_finished_signal, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)()>(_a, &octave_qscintilla::focus_console_after_command_signal, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(const fcn_callback & )>(_a, &octave_qscintilla::interpreter_event, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (octave_qscintilla::*)(const meth_callback & )>(_a, &octave_qscintilla::interpreter_event, 13))
            return;
    }
}

const QMetaObject *octave::octave_qscintilla::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::octave_qscintilla::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6octave17octave_qscintillaE_t>.strings))
        return static_cast<void*>(this);
    return QsciScintilla::qt_metacast(_clname);
}

int octave::octave_qscintilla::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QsciScintilla::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void octave::octave_qscintilla::update_rowcol_indicator_signal(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void octave::octave_qscintilla::execute_command_in_terminal_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void octave::octave_qscintilla::create_context_menu_signal(QMenu * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void octave::octave_qscintilla::context_menu_edit_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void octave::octave_qscintilla::qsci_has_focus_signal(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void octave::octave_qscintilla::status_update(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void octave::octave_qscintilla::show_doc_signal(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void octave::octave_qscintilla::show_symbol_tooltip_signal(const QPoint & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void octave::octave_qscintilla::context_menu_break_condition_signal(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void octave::octave_qscintilla::context_menu_break_once(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void octave::octave_qscintilla::ctx_menu_run_finished_signal(int _t1, QPointer<QTemporaryFile> _t2, QPointer<QTemporaryFile> _t3, bool _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 11
void octave::octave_qscintilla::focus_console_after_command_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void octave::octave_qscintilla::interpreter_event(const fcn_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void octave::octave_qscintilla::interpreter_event(const meth_callback & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
